appngizer.errors — appngizer 1.14.0 documentation

# Source code for appngizer.errors

    class CLIError(Exception):
        '''  '''
    class Error(Exception):
        '''  '''
    class ElementError(Error):
        '''  '''
    class ClientError(Error):
        '''  '''
    class HttpClientBadRequest(Error):
        '''  '''
    class HttpElementConflict(Error):
        '''  '''
    class HttpElementNotFound(Error):
        '''  '''
    class HttpElementForbidden(Error):
        '''  '''
    class HttpServerError(Error):
        '''  '''
    class NotAllowedOp(Error):
        '''  '''
    class XMLValidationError(Error):
        '''  '''